==> tyrus-monitoring-jmx-1.8.2-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/SessionAwareApplicationMonitor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

/**
 * Application events listener and statistics collector.
 * The statistics are collected by aggregating statistics from application endpoints and endpoint sessions.
 * The only difference form {@link org.glassfish.tyrus.ext.monitoring.jmx.SessionlessApplicationMonitor} is that
 * {@link org.glassfish.tyrus.ext.monitoring.jmx.SessionlessApplicationMonitor} does not collect statistics on session
 * level.
 * <p/>
 * It also creates and registers MXBeans that can be used to access these collected statistics.
 * The created MXBeans will allow accessing monitored properties and statistics on application, endpoint and session level.
 * <p/>
 * For monitoring in Grizzly server an instance should be passed to the server in server properties.
 * <pre>
 *     serverProperties.put(ApplicationEventListener.APPLICATION_EVENT_LISTENER, new SessionAwareApplicationMonitor());
 * </pre>
 * For use in servlet container the class name should be passed as a context parameter in web.xml.
 * <pre>{@code
 *     <context-param>
 *         <param-name>org.glassfish.tyrus.core.monitoring.ApplicationEventListener</param-name>
 *         <param-value>org.glassfish.tyrus.ext.monitoring.jmx.SessionAwareApplicationMonitor</param-value>
 *     </context-param>}</pre>
 *
 * @author Petr Janouch (petr.janouch at oracle.com)
 * @see org.glassfish.tyrus.core.monitoring.ApplicationEventListener
 */
public final class SessionAwareApplicationMonitor extends ApplicationMonitor {

    /**
     * Constructor.
     */
    public SessionAwareApplicationMonitor() {
        super(true);
    }
}

==> tyrus-monitoring-jmx-1.11-sources.jar: org/glassfish/tyrus/ext/monitoring/jmx/SessionAwareApplicationMonitor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2014-2015 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.tyrus.ext.monitoring.jmx;

/**
 * Application events listener and statistics collector.
 * The statistics are collected by aggregating statistics from application endpoints and endpoint sessions.
 * The only difference form {@link org.glassfish.tyrus.ext.monitoring.jmx.SessionlessApplicationMonitor} is that
 * {@link org.glassfish.tyrus.ext.monitoring.jmx.SessionlessApplicationMonitor} does not collect statistics on session
 * level.
 * <p/>
 * It also creates and registers MXBeans that can be used to access these collected statistics. The created MXBeans will
 * allow accessing monitored properties and statistics on application, endpoint and session level.
 * <p/>
 * For monitoring in Grizzly server an instance should be passed to the server in server properties.
 * <pre>
 *     serverProperties.put(ApplicationEventListener.APPLICATION_EVENT_LISTENER, new SessionAwareApplicationMonitor());
 * </pre>
 * For use in servlet container the class name should be passed as a context parameter in web.xml.
 * <pre>{@code
 *     <context-param>
 *         <param-name>org.glassfish.tyrus.core.monitoring.ApplicationEventListener</param-name>
 *         <param-value>org.glassfish.tyrus.ext.monitoring.jmx.SessionAwareApplicationMonitor</param-value>
 *     </context-param>}</pre>
 *
 * @author Petr Janouch (petr.janouch at oracle.com)
 * @see org.glassfish.tyrus.core.monitoring.ApplicationEventListener
 */
public final class SessionAwareApplicationMonitor extends ApplicationMonitor {

    /**
     * Constructor.
     */
    public SessionAwareApplicationMonitor() {
        super(true);
    }
}
